@@ -19,7 +19,7 @@ from neurom import NeuriteType, iter_neurites, iter_sections, load_morphology
 from neurom.core.dataformat import COLS
 from neurom.core import Section
 from neurom.features.section import branch_order, section_path_length
-from nptyping import NDArray
+from nptyping import NDArray, Shape, Float
 from scipy.spatial.distance import cdist
 
 from neuror import axon, cut_plane
@@ -234,10 +234,10 @@ class Repair(object):
                  inputfile: Path,
                  axons: Optional[Path] = None,
                  seed: Optional[int] = 0,
-                 cut_leaves_coordinates: Optional[NDArray[(3, Any)]] = None,
+                 cut_leaves_coordinates: Optional[NDArray[Shape["3"], Any]] = None,
                  legacy_detection: bool = False,
                  repair_flags: Optional[Dict[RepairType, bool]] = None,
-                 apical_point: NDArray[3, float] = None,
+                 apical_point: NDArray[Shape["3"], Float] = None,
                  params: Dict = None):
         '''Repair the input morphology
 
@@ -401,7 +401,7 @@ class Repair(object):
             elif type_ == RepairType.trunk:
                 L.debug('Trunk repair is not (nor has ever been) implemented')
             else:
-                raise Exception('Unknown type: {}'.format(type_))
+                raise Exception(f'Unknown type: {type_}')
 
         if plot_file is not None:
             try:
@@ -677,7 +677,7 @@ def repair(inputfile: Path,  # pylint: disable=too-many-arguments
            outputfile: Path,
            axons: Optional[List[Path]] = None,
            seed: int = 0,
-           cut_leaves_coordinates: Optional[NDArray[(3, Any)]] = None,
+           cut_leaves_coordinates: Optional[NDArray[Shape["3"], Any]] = None,
            legacy_detection: bool = False,
            plot_file: Optional[Path] = None,
            repair_flags: Optional[Dict[RepairType, bool]] = None,
